@@ -152,7 +152,7 @@ def parseGemBox(identifier, gembox_text = ""):
         if line.startswith("["): # Start of new message data
             if not inGboxMetadata and currentGemMail.ID != None:
                 # End of message body, append message to GemBox
-                currentGemMail = currentGemMail.setGemtextBody('\n'.join(lines[bodyStart:index]))
+                currentGemMail.setGemtextBody('\n'.join(lines[bodyStart:index]))
                 result.appendGemMail(currentGemMail)
 
             # Start of new message metadata, parse message ID
@@ -224,6 +224,13 @@ def parseGemBox(identifier, gembox_text = ""):
                     if tagValueParts[1] == "true" or tagValueParts == "True" or tagValueParts == "TRUE":
                         value = True
                     currentGemMail.setTag(tagName, last_modification_date_timestamp, value)
+    
+    # Add last gemmail
+    if currentGemMail.ID != None:
+        # End of message body, append message to GemBox
+        currentGemMail.setGemtextBody('\n'.join(lines[bodyStart:index]))
+        result.appendGemMail(currentGemMail)
+    
     return result
 
 
